@@ -26,6 +26,9 @@ import traceback
 
 import shade
 
+from ansible.module_utils.basic import AnsibleModule
+from ansible.module_utils.openstack import openstack_full_argument_spec
+
 
 def main():
     argument_spec = openstack_full_argument_spec(
@@ -55,8 +58,9 @@ def main():
         for _service in cloud.keystone_client.services.list():
             if _service.type == service_type:
                 service = _service
+                service_description = getattr(service, 'description', None)
                 if service.name != service_name or \
-                        service.description != description:
+                        service_description != description:
                     changed = True
                     cloud.keystone_client.services.update(
                         service,
@@ -93,8 +97,6 @@ def main():
         module.exit_json(failed=True, changed=True,
                          msg=repr(traceback.format_exc()))
 
-# import module snippets
-from ansible.module_utils.basic import *  # noqa
-from ansible.module_utils.openstack import *  # noqa
+
 if __name__ == '__main__':
     main()
